@@ -59,10 +59,4 @@ class CreateCertificateRequest(RpcRequest):
 		return self.get_query_params().get('CertificateName')
 
 	def set_CertificateName(self,CertificateName):
-		self.add_query_param('CertificateName',CertificateName)
-
-	def get_HttpsCertId(self):
-		return self.get_query_params().get('HttpsCertId')
-
-	def set_HttpsCertId(self,HttpsCertId):
-		self.add_query_param('HttpsCertId',HttpsCertId)
\ No newline at end of file
+		self.add_query_param('CertificateName',CertificateName)
\ No newline at end of file
